@@ -262,7 +262,7 @@ int main(int argc, char *argv[])
     // enable high dpi support
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
 #endif
-    KAboutData aboutData(QStringLiteral("kdialog"), i18n("KDialog"),
+    KAboutData aboutData(QStringLiteral("kdialog"), QString(),
                          QStringLiteral(KDIALOG_VERSION_STRING), i18n("KDialog can be used to show nice dialog boxes from shell scripts"),
                          KAboutLicense::GPL,
                          i18n("(C) 2000, Nick Thompson"));
@@ -275,6 +275,7 @@ int main(int argc, char *argv[])
     aboutData.addAuthor(i18n("Dawit Alemayehu"), QString(), QStringLiteral("adawit@kde.org"));
     aboutData.addAuthor(i18n("Kai Uwe Broulik"), QString(), QStringLiteral("kde@privat.broulik.de"));
     KAboutData::setApplicationData(aboutData);
+    QGuiApplication::setApplicationDisplayName(QString());
 
     QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
@@ -325,7 +326,7 @@ int main(int argc, char *argv[])
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("print-winid"), i18n("Outputs the winId of each dialog")));
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("dontagain"), i18n("Config file and option name for saving the \"do-not-show/ask-again\" state"),
     QStringLiteral("file:entry")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("slider"), i18n("Slider dialog box, returns selected value"), QStringLiteral("text")));
+    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("slider"), i18n("Slider dialog box, returns selected value (arguments [text] [min] [max] [step])")));
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("dateformat"), i18n("Date format for calendar result and/or default value (Qt-style); defaults to 'ddd MMM d yyyy'"), QStringLiteral("text")));
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("calendar"), i18n("Calendar dialog box, returns selected date"), QStringLiteral("text")));
     /* kdialog originally used --embed for attaching the dialog box.  However this is misleading and so we changed to --attach.
@@ -344,7 +345,10 @@ int main(int argc, char *argv[])
     QApplication::setWindowIcon(QIcon::fromTheme(parser.value(QStringLiteral("icon")), QIcon::fromTheme(QStringLiteral("system-run"))));
 
     const QStringList args = parser.positionalArguments();
-    const QString title = parser.value(QStringLiteral("title"));
+    QString title = parser.value(QStringLiteral("title"));
+    if (title.isEmpty()) {
+        title = i18n("KDialog");
+    }
     const bool separateOutput = parser.isSet(QStringLiteral("separate-output"));
     const bool printWId = parser.isSet(QStringLiteral("print-winid"));
     QString defaultEntry;
@@ -377,8 +381,8 @@ int main(int argc, char *argv[])
     // button labels
     // Initialize with default labels
     KGuiItem okButton = KStandardGuiItem::ok();
-    KGuiItem yesButton = KStandardGuiItem::yes();
-    KGuiItem noButton = KStandardGuiItem::no();
+    KGuiItem yesButton = configuredYes(i18nc("@action:button", "&Yes"));
+    KGuiItem noButton = configuredNo(i18nc("@action:button", "&No"));
     KGuiItem cancelButton = KStandardGuiItem::cancel();
     KGuiItem continueButton = KStandardGuiItem::cont();
 
@@ -405,13 +409,13 @@ int main(int argc, char *argv[])
     QByteArray option;
     if (parser.isSet(QStringLiteral("yesno"))) {
         option = "yesno";
-        type = KMessageBox::QuestionYesNo;
+        type = KMessageBox::QuestionTwoActions;
     } else if (parser.isSet(QStringLiteral("yesnocancel"))) {
         option = "yesnocancel";
-        type = KMessageBox::QuestionYesNoCancel;
+        type = KMessageBox::QuestionTwoActionsCancel;
     } else if (parser.isSet(QStringLiteral("warningyesno"))) {
         option = "warningyesno";
-        type = KMessageBox::WarningYesNo;
+        type = KMessageBox::WarningTwoActions;
         icon = QMessageBox::Warning;
     } else if (parser.isSet(QStringLiteral("warningcontinuecancel"))) {
         option = "warningcontinuecancel";
@@ -419,7 +423,7 @@ int main(int argc, char *argv[])
         icon = QMessageBox::Warning;
     } else if (parser.isSet(QStringLiteral("warningyesnocancel"))) {
         option = "warningyesnocancel";
-        type = KMessageBox::WarningYesNoCancel;
+        type = KMessageBox::WarningTwoActionsCancel;
         icon = QMessageBox::Warning;
     } else if (parser.isSet(QStringLiteral("sorry"))) {
         option = "sorry";
@@ -461,8 +465,8 @@ int main(int argc, char *argv[])
                     }
                 } else {
                     KMessageBox::ButtonCode code;
-                    if (!KMessageBox::shouldBeShownYesNo(dontagain, code)) {
-                        return code == KMessageBox::Yes ? 0 : 1;
+                    if (!KMessageBox::shouldBeShownTwoActions(dontagain, code)) {
+                        return code == KMessageBox::PrimaryAction ? 0 : 1;
                     }
                 }
             } else {
@@ -483,14 +487,14 @@ int main(int argc, char *argv[])
         KMessageBox::Options options = KMessageBox::NoExec;
 
         switch (type) {
-        case KMessageBox::QuestionYesNo:
-        case KMessageBox::WarningYesNo:
+        case KMessageBox::QuestionTwoActions:
+        case KMessageBox::WarningTwoActions:
             buttonBox->setStandardButtons(QDialogButtonBox::Yes | QDialogButtonBox::No);
             KGuiItem::assign(buttonBox->button(QDialogButtonBox::Yes), yesButton);
             KGuiItem::assign(buttonBox->button(QDialogButtonBox::No), noButton);
             break;
-        case KMessageBox::QuestionYesNoCancel:
-        case KMessageBox::WarningYesNoCancel:
+        case KMessageBox::QuestionTwoActionsCancel:
+        case KMessageBox::WarningTwoActionsCancel:
             buttonBox->setStandardButtons(QDialogButtonBox::Yes | QDialogButtonBox::No | QDialogButtonBox::Cancel);
             KGuiItem::assign(buttonBox->button(QDialogButtonBox::Yes), yesButton);
             KGuiItem::assign(buttonBox->button(QDialogButtonBox::No), noButton);
@@ -530,7 +534,7 @@ int main(int argc, char *argv[])
                         KMessageBox::saveDontShowAgainContinue(dontagain);
                     }
                 } else if (ret != QDialogButtonBox::Cancel) {
-                    KMessageBox::saveDontShowAgainYesNo(dontagain, ret == QDialogButtonBox::Yes ? KMessageBox::Yes : KMessageBox::No);
+                    KMessageBox::saveDontShowAgainTwoActions(dontagain, ret == QDialogButtonBox::Yes ? KMessageBox::PrimaryAction : KMessageBox::SecondaryAction);
                 }
             }
         }
@@ -1055,23 +1059,25 @@ QT_WARNING_POP
         }
         return 1; // canceled
     }
-    if (parser.isSet(QStringLiteral("slider"))) {
-        int miniValue = 0;
-        int maxValue = 0;
-        int step = 0;
-        const QString text = Utils::parseString(parser.value(QStringLiteral("slider")));
-        if (args.count() == 3) {
-            miniValue = args.at(0).toInt();
-            maxValue = args.at(1).toInt();
-            step = args.at(2).toInt();
-        }
-        int result = 0;
 
-        const bool returnCode = Widgets::slider(nullptr, title, text, miniValue, maxValue, step, result);
-        if (returnCode) {
-            cout << result << endl;
+    if (parser.isSet(QStringLiteral("slider"))) {
+        if (args.count() == 4) {
+            QString text = Utils::parseString(args.at(0));
+            int miniValue = args.at(1).toInt();
+            int maxValue = args.at(2).toInt();
+            int step = args.at(3).toInt();
+
+            int result = 0;
+
+            const bool returnCode = Widgets::slider(nullptr, title, text, miniValue, maxValue, step, result);
+            if (returnCode) {
+                cout << result << endl;
+            }
+            return returnCode;
+        } else {
+            cerr << qPrintable(i18n("Syntax: --slider <text> <min> <max> <step>")) << endl;
+            return -1;
         }
-        return returnCode;
     }
 
     // --calendar text [--default default] [--dateformat format]
